@@ -95,17 +95,20 @@ OC.L10N.register(
     "Could not write file to disk" : "Nepavyko įrašyti failą į diską",
     "A PHP extension stopped the file upload" : "PHP plėtinys sustabdė failo įkėlimą",
     "No file uploaded or file size exceeds maximum of %s" : "Neįkeltas joks failas arba failo dydis viršija maksimalų %s dydį",
+    "Card not found" : "Kortelė nerasta",
+    "Path is already shared with this card" : "Kelias jau yra bendrinamas su šia kortele",
+    "Invalid date, date format must be YYYY-MM-DD" : "Netinkama data, datos formatas privalo būti MMMM-mm-dd",
     "Personal planning and team project organization" : "Asmeninis planavimas ir komandinių projektų organizavimas",
     "Card details" : "Išsamiau apie kortelę",
     "Add board" : "Pridėti lentą",
     "Select the board to link to a project" : "Pasirinkite lentą, kurią susieti su projektu",
     "Search by board title" : "Ieškoti pagal lentos pavadinimą",
     "Select board" : "Pasirinkti lentą",
-    "Select the card to link to a project" : "Pasirinkite kortelę, kurią susieti su projektu",
     "Select a board" : "Pasirinkite lentą",
     "Select a card" : "Pasirinkti kortelę",
-    "Link to card" : "Susieti su kortele",
     "Cancel" : "Atsisakyti",
+    "Select the card to link to a project" : "Pasirinkite kortelę, kurią susieti su projektu",
+    "Link to card" : "Susieti su kortele",
     "File already exists" : "Failas jau yra",
     "A file with the name {filename} already exists." : "Failas, pavadinimu {filename}, jau yra.",
     "Do you want to overwrite it?" : "Ar norite jį perrašyti?",
@@ -162,10 +165,12 @@ OC.L10N.register(
     "title and color value must be provided" : "privalo būti pateiktos pavadinimo ir spalvos reikšmės",
     "Board name" : "Lentos pavadinimas",
     "Members" : "Nariai",
-    "Upload attachment" : "Įkelti priedą",
     "Add this attachment" : "Pridėti šį priedą",
+    "Unshare file" : "Nustoti bendrinti failą",
     "Delete Attachment" : "Ištrinti priedą",
     "Restore Attachment" : "Atkurti priedą",
+    "Invalid path selected" : "Pasirinktas neteisingas kelias",
+    "Open in sidebar view" : "Atverti šoninės juostos rodinyje",
     "Open in bigger view" : "Atverti didesniame rodinyje",
     "Attachments" : "Priedai",
     "Comments" : "Komentarai",
@@ -210,6 +215,9 @@ OC.L10N.register(
     "Show boards in calendar/tasks" : "Rodyti darbus kalendoriuje/užduotyse",
     "Board details" : "Išsamiau apie lentą",
     "Edit board" : "Taisyti lentą",
+    "Clone board" : "Dubliuoti lentą",
+    "Unarchive board" : "Išarchyvuoti lentą",
+    "Archive board" : "Archyvuoti lentą",
     "Turn on due date reminders" : "Įjungti galutinio termino priminimus",
     "Turn off due date reminders" : "Išjungti galutinio termino priminimus",
     "Due date reminders" : "Galutinio termino priminimai",
@@ -229,6 +237,8 @@ OC.L10N.register(
     "Link to a board" : "Susieti su lenta",
     "Link to a card" : "Susieti su kortele",
     "Something went wrong" : "Kažkas nutiko",
-    "Maximum file size of {size} exceeded" : "Viršytas maksimalus {size} failo dydis"
+    "Maximum file size of {size} exceeded" : "Viršytas maksimalus {size} failo dydis",
+    "Error creating the share" : "Klaida kuriant viešinį",
+    "Share" : "Bendrinti"
 },
 "nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
